******************************
The sherpa.sim.simulate module
******************************

.. currentmodule:: sherpa.sim.simulate

.. automodule:: sherpa.sim.simulate

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      LikelihoodRatioResults
      LikelihoodRatioTest

Class Inheritance Diagram
=========================

.. inheritance-diagram:: LikelihoodRatioResults LikelihoodRatioTest
   :parts: 1
